@@ -33,11 +33,11 @@ class KAccessConfig : public KCModule
 public:
 
     KAccessConfig(QWidget *parent, const QVariantList&);
-    virtual ~KAccessConfig();
+    ~KAccessConfig() override;
 
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
 
 protected Q_SLOTS:
 
